@@ -24,9 +24,8 @@
 #include <string.h>
 #include <sys/stat.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 
 #include <libmissioncontrol/mc-account.h>
 #include <libmissioncontrol/mc-protocol.h>
@@ -51,9 +50,6 @@ typedef struct {
   GtkWidget *vbox_settings;
 
   GtkWidget *combobox_network;
-  GtkWidget *button_add_network;
-  GtkWidget *button_network;
-  GtkWidget *button_remove;
 } EmpathyAccountWidgetIrc;
 
 enum {
@@ -429,7 +425,7 @@ empathy_account_widget_irc_new (McAccount *account)
 {
   EmpathyAccountWidgetIrc *settings;
   gchar *dir, *user_file_with_path, *global_file_with_path;
-  GladeXML *glade;
+  GtkBuilder *gui;
   GtkListStore *store;
   GtkCellRenderer *renderer;
   gchar *filename;
@@ -458,23 +454,18 @@ empathy_account_widget_irc_new (McAccount *account)
   g_free (global_file_with_path);
   g_free (user_file_with_path);
 
-  filename = empathy_file_lookup ("empathy-account-widget-irc.glade",
+  filename = empathy_file_lookup ("empathy-account-widget-irc.ui",
       "libempathy-gtk");
-  glade = empathy_glade_get_file (filename,
-      "vbox_irc_settings",
-      NULL,
+  gui = empathy_builder_get_file (filename,
       "vbox_irc_settings", &settings->vbox_settings,
       "combobox_network", &settings->combobox_network,
-      "button_network", &settings->button_network,
-      "button_add_network", &settings->button_add_network,
-      "button_remove", &settings->button_remove,
       NULL);
   g_free (filename);
 
   /* Fill the networks combobox */
   store = gtk_list_store_new (2, G_TYPE_OBJECT, G_TYPE_STRING);
 
-  gtk_cell_layout_clear (GTK_CELL_LAYOUT (settings->combobox_network)); 
+  gtk_cell_layout_clear (GTK_CELL_LAYOUT (settings->combobox_network));
   renderer = gtk_cell_renderer_text_new ();
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (settings->combobox_network),
       renderer, TRUE);
@@ -493,22 +484,22 @@ empathy_account_widget_irc_new (McAccount *account)
 
   account_widget_irc_setup (settings);
 
-  empathy_account_widget_handle_params (account, glade,
+  empathy_account_widget_handle_params (account, gui,
       "entry_nick", "account",
       "entry_fullname", "fullname",
       "entry_password", "password",
       "entry_quit_message", "quit-message",
       NULL);
 
-  empathy_glade_connect (glade, settings,
+  empathy_builder_connect (gui, settings,
       "vbox_irc_settings", "destroy", account_widget_irc_destroy_cb,
       "button_network", "clicked", account_widget_irc_button_edit_network_clicked_cb,
       "button_add_network", "clicked", account_widget_irc_button_add_network_clicked_cb,
-      "button_remove", "clicked", account_widget_irc_button_remove_clicked_cb,
+      "button_remove_network", "clicked", account_widget_irc_button_remove_clicked_cb,
       "combobox_network", "changed", account_widget_irc_combobox_network_changed_cb,
       NULL);
 
-  g_object_unref (glade);
+  empathy_account_widget_set_default_focus (gui, "entry_nick");
 
-  return settings->vbox_settings;
+  return empathy_builder_unref_and_keep_widget (gui, settings->vbox_settings);
 }
