@@ -15,9 +15,9 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- * 
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ *
  * Authors: Mikael Hallendal <micke@imendio.com>
  *          Richard Hult <richard@imendio.com>
  *          Martyn Russell <martyn@imendio.com>
@@ -31,15 +31,7 @@
 #include <time.h>
 
 #include <glib/gi18n-lib.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtksizegroup.h>
-#include <glade/glade.h>
+#include <gtk/gtk.h>
 
 #include <telepathy-glib/util.h>
 #include <libmissioncontrol/mc-account.h>
@@ -62,15 +54,6 @@
 #define MAX_SCROLL_TIME 0.4 /* seconds */
 #define SCROLL_DELAY 33     /* milliseconds */
 
-#define SCHEMES "(https?|s?ftps?|nntp|news|javascript|about|ghelp|apt|telnet|"\
-		"file|webcal|mailto)"
-#define BODY "([^\\ \\n]+)"
-#define END_BODY "([^\\ \\n]*[^,;\?><()\\ \"\\.\\n])"
-#define URI_REGEX "("SCHEMES"://"END_BODY")" \
-		  "|((mailto:)?"BODY"@"BODY"\\."END_BODY")"\
-		  "|((www|ftp)\\."END_BODY")"
-static GRegex *uri_regex = NULL;
-
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyChatTextView)
 
 typedef struct {
@@ -130,7 +113,7 @@ chat_text_view_url_event_cb (GtkTextTag          *tag,
 							    &start,
 							    &end,
 							    FALSE);
-			    
+
 			    empathy_url_show (GTK_WIDGET (view), str);
 			    g_free (str);
 		    }
@@ -247,12 +230,6 @@ chat_text_view_notify_system_font_cb (EmpathyConf *conf,
 	chat_text_view_system_font_update (view);
 }
 
-static void
-chat_text_view_clear_view_cb (GtkMenuItem *menuitem, EmpathyChatTextView *view)
-{
-	empathy_chat_view_clear (EMPATHY_CHAT_VIEW (view));
-}
-
 static void
 chat_text_view_open_address_cb (GtkMenuItem *menuitem, const gchar *url)
 {
@@ -273,8 +250,8 @@ chat_text_view_copy_address_cb (GtkMenuItem *menuitem, const gchar *url)
 
 static void
 chat_text_view_populate_popup (EmpathyChatTextView *view,
-			  GtkMenu        *menu,
-			  gpointer        user_data)
+			       GtkMenu        *menu,
+			       gpointer        user_data)
 {
 	EmpathyChatTextViewPriv *priv;
 	GtkTextTagTable    *table;
@@ -288,7 +265,7 @@ chat_text_view_populate_popup (EmpathyChatTextView *view,
 	
 	/* Clear menu item */
 	if (gtk_text_buffer_get_char_count (priv->buffer) > 0) {
-		item = gtk_menu_item_new ();
+		item = gtk_separator_menu_item_new ();
 		gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
 		gtk_widget_show (item);
 		
@@ -296,10 +273,9 @@ chat_text_view_populate_popup (EmpathyChatTextView *view,
 		gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
 		gtk_widget_show (item);
 		
-		g_signal_connect (item,
-				  "activate",
-				  G_CALLBACK (chat_text_view_clear_view_cb),
-				  view);
+		g_signal_connect_swapped (item, "activate",
+					  G_CALLBACK (empathy_chat_view_clear),
+					  view);
 	}
 	
 	/* Link context menu items */
@@ -333,21 +309,19 @@ chat_text_view_populate_popup (EmpathyChatTextView *view,
 				"url", str,
 				(GDestroyNotify) g_free);
 	
-	item = gtk_menu_item_new ();
+	item = gtk_separator_menu_item_new ();
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
 	gtk_widget_show (item);
 	
 	item = gtk_menu_item_new_with_mnemonic (_("_Copy Link Address"));
-	g_signal_connect (item,
-			  "activate",
+	g_signal_connect (item, "activate",
 			  G_CALLBACK (chat_text_view_copy_address_cb),
 			  str);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
 	gtk_widget_show (item);
 	
 	item = gtk_menu_item_new_with_mnemonic (_("_Open Link"));
-	g_signal_connect (item,
-			  "activate",
+	g_signal_connect (item, "activate",
 			  G_CALLBACK (chat_text_view_open_address_cb),
 			  str);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
@@ -436,6 +410,8 @@ chat_text_view_append_timestamp (EmpathyChatTextView *view,
 
 		date = g_date_new ();
 		g_date_set_time_t (date, timestamp);
+		/* Translators: timestamp displayed between conversations in
+		 * chat windows (strftime format string) */
 		g_date_strftime (buf, 256, _("%A %B %d %Y"), date);
 		g_string_append (str, buf);
 		g_string_append (str, ", ");
@@ -591,6 +567,7 @@ chat_text_view_finalize (GObject *object)
 	if (priv->scroll_timeout) {
 		g_source_remove (priv->scroll_timeout);
 	}
+	g_object_unref (priv->smiley_manager);
 	
 	G_OBJECT_CLASS (empathy_chat_text_view_parent_class)->finalize (object);
 }
@@ -606,7 +583,7 @@ empathy_chat_text_view_class_init (EmpathyChatTextViewClass *klass)
 	object_class->set_property = chat_text_view_set_property;
 
 	widget_class->size_allocate = chat_text_view_size_allocate;
-	widget_class->drag_motion = chat_text_view_drag_motion; 
+	widget_class->drag_motion = chat_text_view_drag_motion;
 
 	g_object_class_install_property (object_class,
 					 PROP_LAST_CONTACT,
@@ -703,7 +680,7 @@ chat_text_view_scroll_down (EmpathyChatView *view)
 	if (priv->scroll_time) {
 		g_timer_reset (priv->scroll_time);
 	} else {
-		priv->scroll_time = g_timer_new();
+		priv->scroll_time = g_timer_new ();
 	}
 	if (!priv->scroll_timeout) {
 		priv->scroll_timeout = g_timeout_add (SCROLL_DELAY,
@@ -909,7 +886,7 @@ chat_text_view_find_previous (EmpathyChatView *view,
 		if (!new_search && !priv->find_wrapped) {
 			priv->find_wrapped = TRUE;
 			result = chat_text_view_find_previous (view,
-								 search_criteria, 
+								 search_criteria,
 								 FALSE);
 			priv->find_wrapped = FALSE;
 		}
@@ -1023,8 +1000,8 @@ chat_text_view_find_next (EmpathyChatView *view,
 		/* Here we wrap around. */
 		if (!new_search && !priv->find_wrapped) {
 			priv->find_wrapped = TRUE;
-			result = chat_text_view_find_next (view, 
-							     search_criteria, 
+			result = chat_text_view_find_next (view,
+							     search_criteria,
 							     FALSE);
 			priv->find_wrapped = FALSE;
 		}
@@ -1262,6 +1239,7 @@ empathy_chat_text_view_append_body (EmpathyChatTextView *view,
 	GtkTextIter              start_iter, end_iter;
 	GtkTextMark             *mark;
 	GtkTextIter              iter;
+	GRegex                  *uri_regex;
 	GMatchInfo              *match_info;
 	gboolean                 match;
 	gint                     last = 0;
@@ -1273,10 +1251,7 @@ empathy_chat_text_view_append_body (EmpathyChatTextView *view,
 	gtk_text_buffer_get_end_iter (priv->buffer, &start_iter);
 	mark = gtk_text_buffer_create_mark (priv->buffer, NULL, &start_iter, TRUE);
 
-	if (!uri_regex) {
-		uri_regex = g_regex_new (URI_REGEX, 0, 0, NULL);
-	}
-
+	uri_regex = empathy_uri_regex_dup_singleton ();
 	for (match = g_regex_match (uri_regex, body, 0, &match_info); match;
 	     match = g_match_info_next (match_info, NULL)) {
 		if (!g_match_info_fetch_pos (match_info, 0, &s, &e))
@@ -1306,6 +1281,7 @@ empathy_chat_text_view_append_body (EmpathyChatTextView *view,
 		last = e;
 	}
 	g_match_info_free (match_info);
+	g_regex_unref (uri_regex);
 
 	if (last < strlen (body)) {
 		gtk_text_buffer_get_end_iter (priv->buffer, &iter);
