@@ -20,6 +20,9 @@ GType empathy_dispatch_operation_state_get_type (void);
 #include <libempathy/empathy-tp-call.h>
 #define EMPATHY_TYPE_TP_CALL_STATUS empathy_tp_call_status_get_type()
 GType empathy_tp_call_status_get_type (void);
+#include <libempathy/empathy-tp-file.h>
+#define EMPATHY_TYPE_FT_ERROR_ENUM empathy_ft_error_enum_get_type()
+GType empathy_ft_error_enum_get_type (void);
 G_END_DECLS
 
 #endif /* __LIBEMPATHY_ENUM_TYPES_H__ */
