@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  *
  * Authors: Mikael Hallendal <micke@imendio.com>
  *          Richard Hult <richard@imendio.com>
@@ -27,7 +27,6 @@
 #include <string.h>
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <glib/gi18n.h>
 
 #include <libempathy/empathy-utils.h>
@@ -39,6 +38,10 @@
 #include <libempathy-gtk/empathy-contact-list-store.h>
 #include <libempathy-gtk/empathy-gtk-enum-types.h>
 
+#ifdef HAVE_WEBKIT
+#include <libempathy-gtk/empathy-theme-adium.h>
+#endif
+
 #include "empathy-preferences.h"
 
 typedef struct {
@@ -50,6 +53,9 @@ typedef struct {
 	GtkWidget *checkbutton_compact_contact_list;
 	GtkWidget *checkbutton_show_smileys;
 	GtkWidget *combobox_chat_theme;
+	GtkWidget *hbox_adium_theme;
+	GtkWidget *filechooserbutton_adium_theme;
+	GtkWidget *label_invalid_adium_theme;
 	GtkWidget *checkbutton_separate_chat_windows;
 	GtkWidget *checkbutton_autoconnect;
 	GtkWidget *radiobutton_contact_list_sort_by_name;
@@ -65,6 +71,12 @@ typedef struct {
 
 	GtkWidget *treeview_spell_checker;
 
+	GtkWidget *checkbutton_location_publish;
+	GtkWidget *checkbutton_location_reduce_accuracy;
+	GtkWidget *checkbutton_location_resource_network;
+	GtkWidget *checkbutton_location_resource_cell;
+	GtkWidget *checkbutton_location_resource_gps;
+
 	GList     *notify_ids;
 } EmpathyPreferences;
 
@@ -84,19 +96,13 @@ static gboolean preferences_languages_load_foreach       (GtkTreeModel
 static void     preferences_languages_cell_toggled_cb    (GtkCellRendererToggle  *cell,
 							  gchar                  *path_string,
 							  EmpathyPreferences      *preferences);
-static void     preferences_themes_setup                 (EmpathyPreferences      *preferences);
 static void     preferences_widget_sync_bool             (const gchar            *key,
 							  GtkWidget              *widget);
 static void     preferences_widget_sync_string           (const gchar            *key,
 							  GtkWidget              *widget);
-static void     preferences_widget_sync_string_combo     (const gchar            *key,
-							  GtkWidget              *widget);
 static void     preferences_notify_string_cb             (EmpathyConf             *conf,
 							  const gchar            *key,
 							  gpointer                user_data);
-static void     preferences_notify_string_combo_cb       (EmpathyConf             *conf,
-							  const gchar            *key,
-							  gpointer                user_data);
 static void     preferences_notify_bool_cb               (EmpathyConf             *conf,
 							  const gchar            *key,
 							  gpointer                user_data);
@@ -109,9 +115,6 @@ static void     preferences_hookup_toggle_button         (EmpathyPreferences
 static void     preferences_hookup_radio_button          (EmpathyPreferences      *preferences,
 							  const gchar            *key,
 							  GtkWidget              *widget);
-static void     preferences_hookup_string_combo          (EmpathyPreferences      *preferences,
-							  const gchar            *key,
-							  GtkWidget              *widget);
 static void     preferences_hookup_sensitivity           (EmpathyPreferences      *preferences,
 							  const gchar            *key,
 							  GtkWidget              *widget);
@@ -119,8 +122,6 @@ static void     preferences_toggle_button_toggled_cb     (GtkWidget
 							  gpointer                user_data);
 static void     preferences_radio_button_toggled_cb      (GtkWidget              *button,
 							  gpointer                user_data);
-static void     preferences_string_combo_changed_cb      (GtkWidget *button,
-							  gpointer                user_data);
 static void     preferences_destroy_cb                   (GtkWidget              *widget,
 							  EmpathyPreferences      *preferences);
 static void     preferences_response_cb                  (GtkWidget              *widget,
@@ -236,10 +237,6 @@ preferences_setup_widgets (EmpathyPreferences *preferences)
 					  EMPATHY_PREFS_CHAT_SHOW_SMILEYS,
 					  preferences->checkbutton_show_smileys);
 
-	preferences_hookup_string_combo (preferences,
-					 EMPATHY_PREFS_CHAT_THEME,
-					 preferences->combobox_chat_theme);
-
 	preferences_hookup_radio_button (preferences,
 					 EMPATHY_PREFS_CONTACTS_SORT_CRITERIUM,
 					 preferences->radiobutton_contact_list_sort_by_name);
@@ -248,6 +245,38 @@ preferences_setup_widgets (EmpathyPreferences *preferences)
 					  EMPATHY_PREFS_AUTOCONNECT,
 					  preferences->checkbutton_autoconnect);
 
+	preferences_hookup_toggle_button (preferences,
+					  EMPATHY_PREFS_LOCATION_PUBLISH,
+					  preferences->checkbutton_location_publish);
+
+	preferences_hookup_toggle_button (preferences,
+					  EMPATHY_PREFS_LOCATION_RESOURCE_NETWORK,
+					  preferences->checkbutton_location_resource_network);
+	preferences_hookup_sensitivity (preferences,
+					EMPATHY_PREFS_LOCATION_PUBLISH,
+					preferences->checkbutton_location_resource_network);
+
+	preferences_hookup_toggle_button (preferences,
+					  EMPATHY_PREFS_LOCATION_RESOURCE_CELL,
+					  preferences->checkbutton_location_resource_cell);
+	preferences_hookup_sensitivity (preferences,
+					EMPATHY_PREFS_LOCATION_PUBLISH,
+					preferences->checkbutton_location_resource_cell);
+
+	preferences_hookup_toggle_button (preferences,
+					  EMPATHY_PREFS_LOCATION_RESOURCE_GPS,
+					  preferences->checkbutton_location_resource_gps);
+	preferences_hookup_sensitivity (preferences,
+					EMPATHY_PREFS_LOCATION_PUBLISH,
+					preferences->checkbutton_location_resource_gps);
+
+	preferences_hookup_toggle_button (preferences,
+					  EMPATHY_PREFS_LOCATION_REDUCE_ACCURACY,
+					  preferences->checkbutton_location_reduce_accuracy);
+	preferences_hookup_sensitivity (preferences,
+					EMPATHY_PREFS_LOCATION_PUBLISH,
+					preferences->checkbutton_location_reduce_accuracy);
+
 	id = empathy_conf_notify_add (empathy_conf_get (),
 				      EMPATHY_PREFS_UI_COMPACT_CONTACT_LIST,
 				      preferences_compact_contact_list_changed_cb,
@@ -423,7 +452,7 @@ preferences_languages_add (EmpathyPreferences *preferences)
 
 	codes = empathy_spell_get_language_codes ();
 
-	empathy_conf_set_bool (empathy_conf_get(),
+	empathy_conf_set_bool (empathy_conf_get (),
 			       EMPATHY_PREFS_CHAT_SPELL_CHECKER_ENABLED,
 			       codes != NULL);
 	if (!codes) {
@@ -601,34 +630,6 @@ preferences_languages_cell_toggled_cb (GtkCellRendererToggle *cell,
 	preferences_languages_save (preferences);
 }
 
-static void
-preferences_themes_setup (EmpathyPreferences *preferences)
-{
-	GtkComboBox   *combo;
-	GtkListStore  *model;
-	GtkTreeIter    iter;
-	const gchar  **themes;
-	gint           i;
-
-	combo = GTK_COMBO_BOX (preferences->combobox_chat_theme);
-
-	model = gtk_list_store_new (COL_COMBO_COUNT,
-				    G_TYPE_STRING,
-				    G_TYPE_STRING);
-
-	themes = empathy_theme_manager_get_themes ();
-	for (i = 0; themes[i]; i += 2) {
-		gtk_list_store_append (model, &iter);
-		gtk_list_store_set (model, &iter,
-				    COL_COMBO_VISIBLE_NAME, _(themes[i + 1]),
-				    COL_COMBO_NAME, themes[i],
-				    -1);
-	}
-
-	gtk_combo_box_set_model (combo, GTK_TREE_MODEL (model));
-	g_object_unref (model);
-}
-
 static void
 preferences_widget_sync_bool (const gchar *key, GtkWidget *widget)
 {
@@ -660,7 +661,7 @@ preferences_widget_sync_string (const gchar *key, GtkWidget *widget)
 				enum_class = G_ENUM_CLASS (g_type_class_peek (type));
 				enum_value = g_enum_get_value_by_nick (enum_class, value);
 				
-				if (enum_value) { 
+				if (enum_value) {
 					list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
 					toggle_widget = g_slist_nth_data (list, enum_value->value);
 					gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle_widget), TRUE);
@@ -674,48 +675,6 @@ preferences_widget_sync_string (const gchar *key, GtkWidget *widget)
 	}
 }
 
-static void
-preferences_widget_sync_string_combo (const gchar *key, GtkWidget *widget)
-{
-	gchar        *value;
-	GtkTreeModel *model;
-	GtkTreeIter   iter;
-	gboolean      found;
-
-	if (!empathy_conf_get_string (empathy_conf_get (), key, &value)) {
-		return;
-	}
-
-	model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
-
-	found = FALSE;
-	if (value && gtk_tree_model_get_iter_first (model, &iter)) {
-
-		do {
-			gchar *name;
-			gtk_tree_model_get (model, &iter,
-					    COL_COMBO_NAME, &name,
-					    -1);
-
-			if (strcmp (name, value) == 0) {
-				found = TRUE;
-				gtk_combo_box_set_active_iter (GTK_COMBO_BOX (widget), &iter);
-			}
-
-			g_free (name);
-		} while (!found && gtk_tree_model_iter_next (model, &iter));
-	}
-
-	/* Fallback to the first one. */
-	if (!found) {
-		if (gtk_tree_model_get_iter_first (model, &iter)) {
-			gtk_combo_box_set_active_iter (GTK_COMBO_BOX (widget), &iter);
-		}
-	}
-
-	g_free (value);
-}
-
 static void
 preferences_notify_string_cb (EmpathyConf  *conf,
 			      const gchar *key,
@@ -724,13 +683,6 @@ preferences_notify_string_cb (EmpathyConf  *conf,
 	preferences_widget_sync_string (key, user_data);
 }
 
-static void
-preferences_notify_string_combo_cb (EmpathyConf  *conf,
-				    const gchar *key,
-				    gpointer     user_data)
-{
-	preferences_widget_sync_string_combo (key, user_data);
-}
 
 static void
 preferences_notify_bool_cb (EmpathyConf  *conf,
@@ -908,32 +860,6 @@ preferences_hookup_radio_button (EmpathyPreferences *preferences,
 	}
 }
 
-static void
-preferences_hookup_string_combo (EmpathyPreferences *preferences,
-				 const gchar       *key,
-				 GtkWidget         *widget)
-{
-	guint id;
-
-	preferences_widget_sync_string_combo (key, widget);
-
-	g_object_set_data_full (G_OBJECT (widget), "key",
-				g_strdup (key), g_free);
-
-	g_signal_connect (widget,
-			  "changed",
-			  G_CALLBACK (preferences_string_combo_changed_cb),
-			  NULL);
-
-	id = empathy_conf_notify_add (empathy_conf_get (),
-				      key,
-				      preferences_notify_string_combo_cb,
-				      widget);
-	if (id) {
-		preferences_add_id (preferences, id);
-	}
-}
-
 static void
 preferences_hookup_sensitivity (EmpathyPreferences *preferences,
 				const gchar       *key,
@@ -995,39 +921,228 @@ preferences_radio_button_toggled_cb (GtkWidget *button,
 		enum_value = g_enum_get_value (enum_class, g_slist_index (group, button));
 		
 		if (!enum_value) {
-			g_warning ("No GEnumValue for EmpathyContactListSort with GtkRadioButton index:%d", 
+			g_warning ("No GEnumValue for EmpathyContactListSort with GtkRadioButton index:%d",
 				   g_slist_index (group, button));
 			return;
 		}
 
 		value = enum_value->value_nick;
+	} else if (key && strcmp (key, EMPATHY_PREFS_CONTACTS_SORT_CRITERIUM) == 0) {
+           return;
 	}
 
 	empathy_conf_set_string (empathy_conf_get (), key, value);
 }
 
+
 static void
-preferences_string_combo_changed_cb (GtkWidget *combo,
-				     gpointer   user_data)
+preferences_theme_adium_update_visibility (EmpathyPreferences *preferences,
+					   const gchar        *name)
+{
+	if (name && strcmp (name, "adium") == 0) {
+		gtk_widget_show (preferences->hbox_adium_theme);
+	} else {
+		gtk_widget_hide (preferences->hbox_adium_theme);
+		gtk_widget_hide (preferences->label_invalid_adium_theme);
+	}
+}
+
+static void
+preferences_theme_adium_update_validity (EmpathyPreferences *preferences,
+					 const gchar        *path)
+{
+#ifdef HAVE_WEBKIT
+	if (empathy_theme_adium_is_valid (path)) {
+		gtk_widget_hide (preferences->label_invalid_adium_theme);
+	} else {
+		gtk_widget_show (preferences->label_invalid_adium_theme);
+	}
+#endif
+}
+
+static void
+preferences_theme_adium_path_notify_cb (EmpathyConf *conf,
+					const gchar *key,
+					gpointer     user_data)
+{
+	EmpathyPreferences *preferences = user_data;
+	GtkFileChooser     *chooser;
+	gchar              *value;
+	const gchar        *path;
+
+	if (!empathy_conf_get_string (conf, key, &value)) {
+		return;
+	}
+
+	if (EMP_STR_EMPTY (value)) {
+		path = g_get_home_dir ();
+	} else {
+		path = value;
+	}
+
+	chooser = GTK_FILE_CHOOSER (preferences->filechooserbutton_adium_theme);
+	gtk_file_chooser_set_current_folder (chooser, path);
+	preferences_theme_adium_update_validity (preferences, path);
+	g_free (value);
+}
+
+static void
+preferences_theme_adium_file_set_cb (GtkFileChooser     *chooser,
+				     EmpathyPreferences *preferences)
+{
+	gchar *path;
+
+	path = gtk_file_chooser_get_current_folder (chooser);
+	empathy_conf_set_string (empathy_conf_get (),
+				 EMPATHY_PREFS_CHAT_ADIUM_PATH,
+				 path);
+	preferences_theme_adium_update_validity (preferences, path);
+
+	g_free (path);
+}
+
+static void
+preferences_theme_notify_cb (EmpathyConf *conf,
+			     const gchar *key,
+			     gpointer     user_data)
+{
+	EmpathyPreferences *preferences = user_data;
+	GtkComboBox        *combo;
+	gchar              *value;
+	GtkTreeModel       *model;
+	GtkTreeIter         iter;
+	gboolean            found = FALSE;
+
+	if (!empathy_conf_get_string (conf, key, &value)) {
+		return;
+	}
+
+	preferences_theme_adium_update_visibility (preferences, value);
+
+	combo = GTK_COMBO_BOX (preferences->combobox_chat_theme);
+	model = gtk_combo_box_get_model (combo);
+	if (value && gtk_tree_model_get_iter_first (model, &iter)) {
+		gchar *name;
+
+		do {
+			gtk_tree_model_get (model, &iter,
+					    COL_COMBO_NAME, &name,
+					    -1);
+
+			if (strcmp (name, value) == 0) {
+				found = TRUE;
+				gtk_combo_box_set_active_iter (combo, &iter);
+				break;
+			}
+
+			g_free (name);
+		} while (gtk_tree_model_iter_next (model, &iter));
+	}
+
+	/* Fallback to the first one. */
+	if (!found) {
+		if (gtk_tree_model_get_iter_first (model, &iter)) {
+			gtk_combo_box_set_active_iter (combo, &iter);
+		}
+	}
+
+	g_free (value);
+}
+
+static void
+preferences_theme_changed_cb (GtkComboBox        *combo,
+			      EmpathyPreferences *preferences)
 {
-	const gchar  *key;
 	GtkTreeModel *model;
 	GtkTreeIter   iter;
 	gchar        *name;
 
-	key = g_object_get_data (G_OBJECT (combo), "key");
-
-	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter)) {
-		model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+	if (gtk_combo_box_get_active_iter (combo, &iter)) {
+		model = gtk_combo_box_get_model (combo);
 
 		gtk_tree_model_get (model, &iter,
 				    COL_COMBO_NAME, &name,
 				    -1);
-		empathy_conf_set_string (empathy_conf_get (), key, name);
+
+		preferences_theme_adium_update_visibility (preferences, name);
+
+		empathy_conf_set_string (empathy_conf_get (),
+					 EMPATHY_PREFS_CHAT_THEME,
+					 name);
 		g_free (name);
 	}
 }
 
+static void
+preferences_themes_setup (EmpathyPreferences *preferences)
+{
+	GtkComboBox   *combo;
+	GtkCellLayout *cell_layout;
+	GtkCellRenderer *renderer;
+	GtkListStore  *store;
+	const gchar  **themes;
+	gint           i;
+	guint          id;
+
+	combo = GTK_COMBO_BOX (preferences->combobox_chat_theme);
+	cell_layout = GTK_CELL_LAYOUT (combo);
+
+	/* Create the model */
+	store = gtk_list_store_new (COL_COMBO_COUNT,
+				    G_TYPE_STRING,  /* Display name */
+				    G_TYPE_STRING); /* Theme name */
+
+	/* Fill the model */
+	themes = empathy_theme_manager_get_themes ();
+	for (i = 0; themes[i]; i += 2) {
+		gtk_list_store_insert_with_values (store, NULL, -1,
+			COL_COMBO_VISIBLE_NAME, _(themes[i + 1]),
+			COL_COMBO_NAME, themes[i],
+			-1);
+	}
+
+	/* Add cell renderer */
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (cell_layout, renderer, TRUE);
+	gtk_cell_layout_set_attributes (cell_layout, renderer,
+		"text", COL_COMBO_VISIBLE_NAME, NULL);
+
+	gtk_combo_box_set_model (combo, GTK_TREE_MODEL (store));
+	g_object_unref (store);
+
+	g_signal_connect (combo, "changed",
+			  G_CALLBACK (preferences_theme_changed_cb),
+			  preferences);
+
+	/* Select the theme from the gconf key and track changes */
+	preferences_theme_notify_cb (empathy_conf_get (),
+				     EMPATHY_PREFS_CHAT_THEME,
+				     preferences);
+	id = empathy_conf_notify_add (empathy_conf_get (),
+				      EMPATHY_PREFS_CHAT_THEME,
+				      preferences_theme_notify_cb,
+				      preferences);
+	if (id) {
+		preferences_add_id (preferences, id);
+	}
+
+	g_signal_connect (preferences->filechooserbutton_adium_theme,
+			  "file-set",
+			  G_CALLBACK (preferences_theme_adium_file_set_cb),
+			  preferences);
+	/* Select the adium path from the gconf key and track changes */
+	preferences_theme_adium_path_notify_cb (empathy_conf_get (),
+						EMPATHY_PREFS_CHAT_ADIUM_PATH,
+						preferences);
+	id = empathy_conf_notify_add (empathy_conf_get (),
+				      EMPATHY_PREFS_CHAT_ADIUM_PATH,
+				      preferences_theme_adium_path_notify_cb,
+				      preferences);
+	if (id) {
+		preferences_add_id (preferences, id);
+	}
+}
+
 static void
 preferences_response_cb (GtkWidget         *widget,
 			 gint               response,
@@ -1057,8 +1172,9 @@ GtkWidget *
 empathy_preferences_show (GtkWindow *parent)
 {
 	static EmpathyPreferences *preferences;
-	GladeXML                 *glade;
-	gchar                    *filename;
+	GtkBuilder                *gui;
+	gchar                     *filename;
+	GtkWidget                 *page;
 
 	if (preferences) {
 		gtk_window_present (GTK_WINDOW (preferences->dialog));
@@ -1067,16 +1183,17 @@ empathy_preferences_show (GtkWindow *parent)
 
 	preferences = g_new0 (EmpathyPreferences, 1);
 
-	filename = empathy_file_lookup ("empathy-preferences.glade", "src");
-	glade = empathy_glade_get_file (filename,
-		"preferences_dialog",
-		NULL,
+	filename = empathy_file_lookup ("empathy-preferences.ui", "src");
+	gui = empathy_builder_get_file (filename,
 		"preferences_dialog", &preferences->dialog,
 		"notebook", &preferences->notebook,
 		"checkbutton_show_avatars", &preferences->checkbutton_show_avatars,
 		"checkbutton_compact_contact_list", &preferences->checkbutton_compact_contact_list,
 		"checkbutton_show_smileys", &preferences->checkbutton_show_smileys,
 		"combobox_chat_theme", &preferences->combobox_chat_theme,
+		"hbox_adium_theme", &preferences->hbox_adium_theme,
+		"filechooserbutton_adium_theme", &preferences->filechooserbutton_adium_theme,
+		"label_invalid_adium_theme", &preferences->label_invalid_adium_theme,
 		"checkbutton_separate_chat_windows", &preferences->checkbutton_separate_chat_windows,
 		"checkbutton_autoconnect", &preferences->checkbutton_autoconnect,
 		"radiobutton_contact_list_sort_by_name", &preferences->radiobutton_contact_list_sort_by_name,
@@ -1088,16 +1205,20 @@ empathy_preferences_show (GtkWindow *parent)
 		"checkbutton_sounds_disabled_away", &preferences->checkbutton_sounds_disabled_away,
 		"treeview_sounds", &preferences->treeview_sounds,
 		"treeview_spell_checker", &preferences->treeview_spell_checker,
+		"checkbutton_location_publish", &preferences->checkbutton_location_publish,
+		"checkbutton_location_reduce_accuracy", &preferences->checkbutton_location_reduce_accuracy,
+		"checkbutton_location_resource_network", &preferences->checkbutton_location_resource_network,
+		"checkbutton_location_resource_cell", &preferences->checkbutton_location_resource_cell,
+		"checkbutton_location_resource_gps", &preferences->checkbutton_location_resource_gps,
 		NULL);
 	g_free (filename);
 
-	empathy_glade_connect (glade,
-			      preferences,
+	empathy_builder_connect (gui, preferences,
 			      "preferences_dialog", "destroy", preferences_destroy_cb,
 			      "preferences_dialog", "response", preferences_response_cb,
 			      NULL);
 
-	g_object_unref (glade);
+	g_object_unref (gui);
 
 	g_object_add_weak_pointer (G_OBJECT (preferences->dialog), (gpointer) &preferences);
 
@@ -1119,6 +1240,14 @@ empathy_preferences_show (GtkWindow *parent)
 		gtk_widget_show (page);
 	}
 
+	page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (preferences->notebook), 3);
+#if HAVE_GEOCLUE
+	gtk_widget_show (page);
+#else
+	gtk_widget_hide (page);
+#endif
+
+
 	if (parent) {
 		gtk_window_set_transient_for (GTK_WINDOW (preferences->dialog),
 					      GTK_WINDOW (parent));
